Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(397)

Unified Diff: Source/bindings/v8/V8LazyEventListener.cpp

Issue 93723003: Rename HTMLElement::form() to formOwner(). (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | Source/core/html/HTMLButtonElement.idl » ('j') | Source/core/html/HTMLFormControlElement.h » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/bindings/v8/V8LazyEventListener.cpp
diff --git a/Source/bindings/v8/V8LazyEventListener.cpp b/Source/bindings/v8/V8LazyEventListener.cpp
index 36383cb2477d86ad222af19b5ee2c92d627ab2ae..1d80ffd89bf48a68ca3abadbe462c0789c05fde7 100644
--- a/Source/bindings/v8/V8LazyEventListener.cpp
+++ b/Source/bindings/v8/V8LazyEventListener.cpp
@@ -136,7 +136,7 @@ void V8LazyEventListener::prepareListenerObject(ExecutionContext* context)
// FIXME: Remove the following 'with' hack.
//
// Nodes other than the document object, when executing inline event
// handlers push document, form, and the target node on the scope chain.
// We do this by using 'with' statement.
// See chrome/fast/forms/form-action.html
// chrome/fast/forms/selected-index-value.html
@@ -171,7 +171,7 @@ void V8LazyEventListener::prepareListenerObject(ExecutionContext* context)
HTMLFormElement* formElement = 0;
if (m_node && m_node->isHTMLElement())
- formElement = toHTMLElement(m_node)->form();
+ formElement = toHTMLElement(m_node)->formOwner();
v8::Handle<v8::Object> nodeWrapper = toObjectWrapper<Node>(m_node, isolate);
v8::Handle<v8::Object> formWrapper = toObjectWrapper<HTMLFormElement>(formElement, isolate);
« no previous file with comments | « no previous file | Source/core/html/HTMLButtonElement.idl » ('j') | Source/core/html/HTMLFormControlElement.h » ('J')
@@ -136,7 +136,7 @@ void V8LazyEventListener::prepareListenerObject(ExecutionContext* context)
//
// Nodes other than the document object, when executing inline event
- // handlers push document, form, and the target node on the scope chain.
+ // handlers push document, form owner, and the target node on the scope chain.
// We do this by using 'with' statement.
// See chrome/fast/forms/form-action.html

Powered by Google App Engine
This is Rietveld 408576698